@@ -22,13 +22,13 @@
 #include "tellico_debug.h"
 #include "latin1literal.h"
 
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kaccelmanager.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeaccelmanager.h>
 #include <kiconloader.h>
-#include <kdeversion.h>
+#include <tdeversion.h>
 #include <kpushbutton.h>
-#include <kaccel.h>
+#include <tdeaccel.h>
 
 #include <tqlayout.h>
 #include <tqstringlist.h>
@@ -85,7 +85,7 @@ EntryEditDialog::EntryEditDialog(TQWidget* parent_, const char* name_)
   setButtonGuiItem(m_nextBtn, next);
   setButtonGuiItem(m_prevBtn, prev);
 
-  KAccel* accel = new KAccel(this);
+  TDEAccel* accel = new TDEAccel(this);
   accel->insert(TQString::fromLatin1("Go Prev"), TQString(), prev.toolTip(), TQt::Key_PageUp,
                 Controller::self(), TQT_SLOT(slotGoPrevEntry()));
   accel->insert(TQString::fromLatin1("Go Next"), TQString(), next.toolTip(), TQt::Key_PageDown,
@@ -264,7 +264,7 @@ void EntryEditDialog::setLayout(Data::CollPtr coll_) {
 
   // update keyboard accels
   // only want to manage tabBar()
-  KAcceleratorManager::manage(m_tabs->tabBar());
+  TDEAcceleratorManager::manage(m_tabs->tabBar());
 
   m_tabs->setCurrentPage(0);
 
